@@ -14,11 +14,11 @@
 #include "qsflphonedialer.h"
 #include "qskypedialer.h"
 
+#include <KContacts/PhoneNumber>
 #include <KDialogJobUiDelegate>
 #include <KIO/CommandLauncherJob>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <kcontacts/phonenumber.h>
 
 #include <QDesktopServices>
 
