@@ -4,16 +4,19 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ADDEMAILADDRESSJOB_H
-#define ADDEMAILADDRESSJOB_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include <KJob>
 
+#include <memory>
+
 namespace Akonadi
 {
 class Item;
+class AddEmailAddressJobPrivate;
+
 /**
  * @short A job to add a new contact with a given email address to Akonadi.
  *
@@ -56,10 +59,9 @@ Q_SIGNALS:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    friend class AddEmailAddressJobPrivate;
+    std::unique_ptr<AddEmailAddressJobPrivate> const d;
     //@endcond
 };
 }
 
-#endif
